==> hplip-1.7.4a.tar.bz2: hplip-1.7.4a/scan/sane/io.h <==
/************************************************************************************\

  io.h - HP SANE backend for multi-function peripherals (libsane-hpaio)

  (c) 2001-2006 Copyright Hewlett-Packard Development Company, LP

  Permission is hereby granted, free of charge, to any person obtaining a copy 
  of this software and associated documentation files (the "Software"), to deal 
  in the Software without restriction, including without limitation the rights 
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
  of the Software, and to permit persons to whom the Software is furnished to do 
  so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

  Contributing Author: Don Welch, David Suffield 

\************************************************************************************/

#if !defined(_IO_H)
#define _IO_H

#include "sane.h"
#include "hplip_api.h"

int ResetDevices( SANE_Device *** devices );
int SendScanEvent( char * device_uri, int event, char * type );
int GetScannerType( SANE_String model );
int ProbeDevices( SANE_Device *** devices );
int GetPml(int hd, int channel, char *oid, char *buf, int size, int *result, int *type, int *pml_result);
int SetPml(int hd, int channel, char *oid, int type, char *buf, int size, int *result, int *pml_result);
int ReadChannelEx(int deviceid, int channelid, unsigned char * buffer, int length, int timeout);

extern HplipSession *hplip_session;

#endif

==> hplip-2.8.4.tar.bz2: hplip-2.8.4/scan/sane/io.h <==
/************************************************************************************\

  io.h - HP SANE backend for multi-function peripherals (libsane-hpaio)

  (c) 2001-2006 Copyright Hewlett-Packard Development Company, LP

  Permission is hereby granted, free of charge, to any person obtaining a copy 
  of this software and associated documentation files (the "Software"), to deal 
  in the Software without restriction, including without limitation the rights 
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
  of the Software, and to permit persons to whom the Software is furnished to do 
  so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

  Contributing Author: Don Welch, David Suffield 

\************************************************************************************/

#if !defined(_IO_H)
#define _IO_H

#include "sane.h"
#include "hpmud.h"

int __attribute__ ((visibility ("hidden"))) InitDbus(void);
int __attribute__ ((visibility ("hidden"))) SendScanEvent(char * device_uri, int event);
int __attribute__ ((visibility ("hidden"))) ReadChannelEx(int deviceid, int channelid, unsigned char * buffer, int length, int timeout);

#define EVENT_START_SCAN_JOB 2000
#define EVENT_END_SCAN_JOB 2001
#define EVENT_SCANNER_FAIL 2002

#define DBUS_INTERFACE "com.hplip.Service"
#define DBUS_PATH "/"

#endif
